.header.v-toolbar[data-v-a88771f6] .v-toolbar-title{margin-inline-start:0px;font-size:x-large;font-weight:700}.carousel-wrapper[data-v-a88771f6]{background-color:rgb(var(--v-theme-panel));padding:10px;border-radius:5px}.widget-row[data-v-a88771f6]{margin-bottom:20px;margin-left:0;padding-left:0}.disabled[data-v-a88771f6]{opacity:.2}.enabled[data-v-a88771f6]{opacity:1}.widget-row-panel-item[data-v-a88771f6]{margin-bottom:10px}.v-slide-group__prev[data-v-a88771f6]{min-width:0px!important}.v-slide-group__prev.v-slide-group__prev--disabled[data-v-a88771f6]{visibility:hidden;margin-right:-15px}.v-slide-group__next[data-v-a88771f6]{min-width:15px!important}.v-slide-group__next.v-slide-group__next--disabled[data-v-a88771f6]{visibility:hidden}
