import{ay as b,a3 as f,aI as s,aA as t,aY as p,aD as a,bL as k,aG as n,a$ as h,az as m,r as C,o as r,E as v,aB as c,M as g,aV as V,aN as R,b5 as B,bK as $,ah as x,aH as M,bh as A,bM as I,aQ as u,_ as N}from"./index-BRUnowC8.js";import{P}from"./PanelviewItemCompact-CsJmi5IT.js";import{V as T}from"./VToolbar-DS4mUdOC.js";import{V as z}from"./VAlert-DQxypmdN.js";const E=b({__name:"Carousel",setup(e){return f(()=>{document.documentElement.style.setProperty("--swiper-navigation-color","primary")}),(d,l)=>{const w=p("swiper");return t(),s(w,{"slides-per-view":a(k)(d.$vuetify.display.width)+.5,"free-mode":!0,navigation:!1,mousewheel:{forceToAxis:!0,releaseOnEdges:!0}},{default:n(()=>[h(d.$slots,"default")]),_:3},8,["slides-per-view"])}}}),O={class:"mr-3"},D={key:0},L={class:"carousel-wrapper"},W=b({__name:"WidgetRow",props:{widgetRow:{},editMode:{type:Boolean},showProviderOnCover:{type:Boolean}},emits:["update:settings"],setup(e,{emit:d}){const l=d;return(w,o)=>{const y=p("swiper-slide");return t(),m("div",{class:C(`widget-row ${e.widgetRow.settings&&!e.widgetRow.settings.enabled?"disabled":""}`)},[r(T,{class:"header",color:"transparent"},{title:n(()=>[v("span",O,R(e.widgetRow.title),1),e.widgetRow.subtitle&&a(B)("bp6")?(t(),s($,{key:0,inline:"",outlined:"",text:e.widgetRow.subtitle,density:"compact",size:"small"},null,8,["text"])):c("",!0)]),append:n(()=>[e.editMode&&e.widgetRow.settings?(t(),m("div",D,[e.widgetRow.settings.position!==0?(t(),s(g,{key:0,icon:"mdi-chevron-up",class:"enabled",onClick:o[0]||(o[0]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position-1}))})):c("",!0),r(g,{icon:"mdi-chevron-down",onClick:o[1]||(o[1]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position+1}))}),r(g,{icon:e.widgetRow.settings.enabled?"mdi-checkbox-marked":"mdi-checkbox-blank-outline",onClick:o[2]||(o[2]=i=>l("update:settings",{...e.widgetRow.settings,enabled:!e.widgetRow.settings.enabled}))},null,8,["icon"])])):e.widgetRow.provider?(t(),s(V,{key:1,domain:e.widgetRow.provider,size:24},null,8,["domain"])):c("",!0)]),_:1}),v("div",L,[e.widgetRow.items.length>0?(t(),s(E,{key:0},{default:n(()=>[(t(!0),m(x,null,M(e.widgetRow.items,i=>(t(),s(y,{key:i.uri},{default:n(()=>[r(P,{item:i,"show-provider-on-cover":e.showProviderOnCover,"permanent-overlay":![a(u).ALBUM,a(u).TRACK,a(u).RADIO].includes(i.media_type),"is-available":a(I)(i),disabled:e.editMode},null,8,["item","show-provider-on-cover","permanent-overlay","is-available","disabled"])]),_:2},1024))),128))]),_:1})):(t(),s(z,{key:1},{default:n(()=>[A(R(w.$t("no_content")),1)]),_:1}))])],2)}}}),H=N(W,[["__scopeId","data-v-a88771f6"]]);export{H as W};
