import{M as f}from"./index-kQIztB-E.js";import{i as c,ay as m,a_ as d,u as p,aI as h,aA as C,aK as _,aH as v,ae as y,aD as u,cL as P,aG as b,a$ as w,_ as g}from"./index-BRUnowC8.js";const k=(a,s)=>{const r=c(()=>{const{variant:t,...e}=a;return{...e,fluid:a.fluid!==!1}}),o=c(()=>{const t=f(a.variant).with("panel",()=>["container-main","container-panel",s?"container-panel--dark":"container-panel--light"]).with("compact",()=>["container-main","container-compact"]).with("comfortable",()=>["container-main","container-comfortable"]).with("default",()=>["container-main","container-default"]).otherwise(()=>["container-main","container-default"]),e=[];return a.class&&(typeof a.class=="string"?e.push(a.class):Array.isArray(a.class)?e.push(...a.class):Object.entries(a.class).forEach(([n,i])=>{i&&e.push(n)})),[...t,...e].join(" ")});return{containerProps:r,containerClasses:o}},A={variant:"default",fluid:!0},B=m({__name:"Container",props:d({variant:{},fluid:{type:Boolean},tag:{},class:{},style:{}},A),setup(a){const s=a,r=p(),o=c(()=>r.current.value.dark),{containerProps:t,containerClasses:e}=k(s,o.value);return(n,i)=>(C(),h(P,y(u(t),{class:u(e)}),_({_:2},[v(n.$slots,(D,l)=>({name:l,fn:b(()=>[w(n.$slots,l,{},void 0,!0)])}))]),1040,["class"]))}}),x=g(B,[["__scopeId","data-v-b8d6ce90"]]);export{x as C};
