.header.v-toolbar[data-v-771a3548] .v-toolbar-title{margin-inline-start:0px;font-size:x-large;font-weight:700}.widget-row[data-v-771a3548]{margin-bottom:10px;margin-left:0;margin-right:0;padding-left:0}.disabled[data-v-771a3548]{opacity:.2}.enabled[data-v-771a3548]{opacity:1}.widget-row-panel-item[data-v-771a3548]{margin-bottom:10px}.v-slide-group__prev[data-v-771a3548]{min-width:0px!important}.v-slide-group__prev.v-slide-group__prev--disabled[data-v-771a3548]{visibility:hidden;margin-right:-15px}.v-slide-group__next[data-v-771a3548]{min-width:15px!important}.v-slide-group__next.v-slide-group__next--disabled[data-v-771a3548]{visibility:hidden}[data-v-771a3548] .swiper-slide{width:auto}.v-progress-circular[data-v-22a0cc44]{display:block;margin-inline:auto}.editButton[data-v-22a0cc44]{float:right;margin-bottom:10px}.user-header-item[data-v-22a0cc44] .v-list-item__prepend{margin-inline-end:8px;margin-left:-8px}.user-avatar[data-v-22a0cc44]{border:1px solid rgba(var(--v-border-color),var(--v-border-opacity))}
