import{M as y}from"./index-kQIztB-E.js";import{i as r,ay as f,a_ as B,aI as c,aA as u,M as b,ae as d,aD as p,aK as m,aG as v,aB as h,aL as w,aH as g,a$ as x,_ as k}from"./index-BRUnowC8.js";const $=(...e)=>e.filter(Boolean).join(" "),C=e=>{const l=r(()=>{const{variant:i,nav:a,...n}=e,t={...n,"aria-label":e.title||e["aria-label"]};return y(i).with("responsive",()=>({...t,icon:!0,variant:"text",ripple:e.ripple!==!1,class:e.class?`btn-responsive ${e.class}`:"btn-responsive",style:{height:"var(--responsive-button-size, min(calc(100vw - 40px), calc(100vh - 340px)))",width:"var(--responsive-button-size, min(calc(100vw - 40px), calc(100vh - 340px)))",...typeof e.style=="object"?e.style:{}}})).with("icon",()=>({...t,icon:!0,variant:"plain",ripple:e.ripple!==!1,class:e.class?`btn-icon ${e.class}`:"btn-icon"})).with("list",()=>({...t,variant:"plain",density:"comfortable",ripple:e.ripple!==!1,class:e.class?`btn-list ${e.class}`:"btn-list"})).with("plain",()=>({...t,variant:"plain",ripple:e.ripple!==!1})).with("default",()=>({...t,variant:"text",ripple:e.ripple!==!1})).otherwise(()=>({...t,variant:"text",ripple:e.ripple!==!1}))}),o=r(()=>$("button",e.variant&&`button--${e.variant}`,e.nav&&"button--nav"));return{buttonProps:l,buttonClasses:o}},P={variant:"default",ripple:!0},M=f({__name:"Button",props:B({variant:{},nav:{type:Boolean},icon:{type:[String,Boolean]},ripple:{type:Boolean},height:{},width:{},size:{},title:{},disabled:{type:Boolean},color:{},to:{},block:{type:Boolean},density:{},flat:{type:Boolean},loading:{type:Boolean},outlined:{type:Boolean},rounded:{type:[Boolean,String,Number]},tag:{},text:{type:Boolean},type:{},value:{},active:{type:Boolean},append:{type:Boolean},exact:{type:Boolean},replace:{type:Boolean},slim:{type:Boolean},stacked:{type:Boolean},class:{},style:{},"aria-label":{}},P),emits:["click"],setup(e){const l=e,{buttonProps:o,buttonClasses:i}=C(l);return(a,n)=>(u(),c(b,d(p(o),{class:p(i),onClick:n[0]||(n[0]=t=>a.$emit("click",t))}),m({default:v(()=>[e.icon&&typeof e.icon=="string"?(u(),c(w,{key:0,icon:e.icon},null,8,["icon"])):h("",!0)]),_:2},[g(a.$slots,(t,s)=>({name:s,fn:v(()=>[x(a.$slots,s,{},void 0,!0)])}))]),1040,["class"]))}}),I=k(M,[["__scopeId","data-v-f097a0e8"]]);export{I as M,$ as m};
