.v-slider.v-input--horizontal .v-input__control[data-v-e4b3dbf4]{min-height:5px}.v-slider.v-input--horizontal[data-v-e4b3dbf4]{margin-inline:unset!important}.volumesliderrow[data-v-73b9316d]{margin-top:0;padding-top:0;padding-bottom:0;height:40px;min-height:40px}.volumesliderrow[data-v-73b9316d] .v-list-item__content{height:40px;min-height:40px;overflow:visible!important;align-content:center}.heading[data-v-73b9316d]{margin-bottom:5px;height:35px}.volumecaption[data-v-73b9316d]{width:34px;text-align:right;margin-right:-20px}.expandbtn[data-v-73b9316d]{margin-right:-12px}.powerbtn[data-v-73b9316d]{right:8px}.volumesliderrow[data-v-73b9316d] .v-list-item__prepend{width:40px;margin-left:-20px}.volumesliderrow[data-v-73b9316d] .v-list-item__append{width:20px}.checkbox[data-v-73b9316d]{margin-right:-5px;width:25px;margin-top:-30px;height:22px!important;min-height:22px!important;display:unset}.syncbtn[data-v-73b9316d]{margin-right:-32px;height:25px!important;padding-bottom:20px}.panel-item-details[data-v-b26841b7]{width:100%;margin:0!important;padding:0!important;min-height:72px}.panel-item-details[data-v-b26841b7] .v-list-item__content{display:flex;flex-direction:column;justify-content:center;min-height:60px}.volumesliderrow[data-v-b26841b7]{margin-top:0;padding-top:0;padding-bottom:0;height:24px;min-height:24px}.volumecaption[data-v-b26841b7]{width:25px;text-align:right;margin-right:0}.volumesliderrow[data-v-b26841b7] .v-list-item__prepend{width:40px;margin-left:-25px}.volumesliderrow[data-v-b26841b7] .v-expansion-panel-text__wrapper{padding:0}.player-media-thumb[data-v-b26841b7]{margin-right:10px}.media-thumb[data-v-b26841b7]{width:60px;height:60px;border-radius:4px;background-color:#0000004d}.icon-thumb[data-v-b26841b7]{width:60px;height:60px;border-radius:4px;background-color:#0000004d;display:flex;align-items:center;justify-content:center}.media-thumb[data-v-b26841b7]{width:55px;height:55px;border-radius:4px;background-color:#0000004d}.icon-thumb[data-v-b26841b7]{width:55px;height:55px;margin-top:5px;border-radius:4px;background-color:#0000004d;display:inline-table}.panel-item[data-v-b26841b7]{border-style:ridge;border-width:thin;border-color:#cccccc5e;padding:5px 8px;background-color:#a2bcff1a;opacity:1;transition:opacity .4s ease-in-out;border-radius:6px;margin:5px 0 8px;height:100%;width:auto}.panel-item-idle[data-v-b26841b7]{opacity:.8}.panel-item-off[data-v-b26841b7]{opacity:.6}.panel-item-selected[data-v-b26841b7]{border-color:#2f2f2f5e;background-color:#a2bcff66}.player-command-btn[data-v-b26841b7]{width:35px;min-width:35px;margin-left:5px}.group-badge[data-v-b26841b7] .v-badge__badge{font-size:10px;height:16px;min-width:16px;padding:0 3px 0 4px}
