.container-default[data-v-b8d6ce90]{padding:10px}.container-compact[data-v-b8d6ce90]{padding:5px}.container-comfortable[data-v-b8d6ce90]{padding:20px}.container-panel[data-v-b8d6ce90]{padding:10px}.container-panel--light[data-v-b8d6ce90]{background:#f5f5f5}@media (min-width: 1920px){.container-main[data-v-b8d6ce90]{max-width:unset!important}}@media (min-width: 1280px){.container-main[data-v-b8d6ce90]{max-width:unset!important}}@media (min-width: 960px){.container-main[data-v-b8d6ce90]{max-width:unset!important}}
