.v-infinite-scroll--horizontal{display:flex;flex-direction:row;overflow-x:auto}.v-infinite-scroll--horizontal .v-infinite-scroll-intersect{height:100%;width:var(--v-infinite-margin-size, 1px)}.v-infinite-scroll--vertical{display:flex;flex-direction:column;overflow-y:auto}.v-infinite-scroll--vertical .v-infinite-scroll-intersect{height:1px;width:100%}.v-infinite-scroll-intersect{overflow:hidden;pointer-events:none;margin-top:var(--v-infinite-margin);margin-bottom:calc(var(--v-infinite-margin) * -1)}.v-infinite-scroll-intersect:nth-child(2){--v-infinite-margin: var(--v-infinite-margin-size, 1px)}.v-infinite-scroll-intersect:nth-last-child(2){--v-infinite-margin: calc(var(--v-infinite-margin-size, 1px) * -1)}.v-infinite-scroll__side{align-items:center;display:flex;justify-content:center;padding:8px;transition-property:padding;transition-duration:.3s;transition-timing-function:cubic-bezier(.4,0,.2,1)}.v-infinite-scroll__side:empty,.v-infinite-scroll__side:has(>div:only-child:empty){padding:0}
