.user-name-box[data-v-8cbf5f8f],.user-name-box[data-v-9638370d]{background:rgba(var(--v-theme-error),.08);border-left:3px solid rgb(var(--v-theme-error));padding:12px 16px;border-radius:4px;font-weight:500;font-size:.938rem}.section-subtitle[data-v-19f1861f]{color:var(--v-theme-secondary);font-size:.813rem;margin:16px 0 12px;line-height:1.4}.section-header-with-action[data-v-19f1861f]{display:flex;justify-content:space-between;align-items:flex-start;gap:16px;margin-bottom:12px;flex-wrap:wrap}.empty-state[data-v-19f1861f]{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:48px 24px;border:2px dashed rgba(var(--v-border-color),var(--v-border-opacity));border-radius:8px;text-align:center}.empty-state .v-avatar[data-v-19f1861f]{display:flex;align-items:center;justify-content:center;border:1px solid rgba(var(--v-border-color),var(--v-border-opacity))}.empty-state .v-avatar .v-icon[data-v-19f1861f]{margin:0!important}.tokens-list[data-v-19f1861f]{border:1px solid rgba(var(--v-border-color),var(--v-border-opacity));border-radius:8px;overflow:hidden;padding:10px}.token-meta[data-v-19f1861f]{display:flex;gap:8px;align-items:center;flex-wrap:wrap;font-size:.875rem}.token-divider[data-v-19f1861f]{color:rgb(var(--v-theme-on-surface-variant))}.tokens-list[data-v-19f1861f] .v-avatar{display:flex;align-items:center;justify-content:center;border:1px solid rgba(var(--v-border-color),var(--v-border-opacity))}.tokens-list[data-v-19f1861f] .v-avatar .v-icon{margin:0!important}@media (max-width: 600px){.section-header-with-action[data-v-19f1861f]{flex-direction:column;align-items:stretch}}.token-name-box[data-v-026d0253]{background:rgba(var(--v-theme-error),.08);border-left:3px solid rgb(var(--v-theme-error));padding:12px 16px;border-radius:4px;font-weight:500;font-size:.938rem}.users-header[data-v-4952d4ff]{display:flex;align-items:stretch;justify-content:space-between;gap:16px;flex-wrap:wrap;padding:20px 20px 6px}.add-user-btn[data-v-4952d4ff]{flex-shrink:0;align-self:center}@media (max-width: 960px){.users-header[data-v-4952d4ff]{flex-direction:column;align-items:stretch}.add-user-btn[data-v-4952d4ff]{width:100%;align-self:stretch}}.user-avatar-wrapper[data-v-4952d4ff]{display:flex;align-items:center;justify-content:center}.user-avatar-wrapper[data-v-4952d4ff] .v-icon{margin-inline-end:0!important}.user-avatar-wrapper[data-v-4952d4ff] .v-avatar{display:flex;align-items:center;justify-content:center;border:1px solid rgba(var(--v-border-color),var(--v-border-opacity))}.user-avatar-wrapper[data-v-4952d4ff] .v-avatar .v-icon{margin:0!important}
