.list-item-main[data-v-e242bb46]{border-radius:4px!important;padding:7px 0 7px 7px!important}.list-item-main[data-v-e242bb46] .v-list-item__append{display:flex;justify-content:flex-end;align-items:center;padding:0}.list-item-main[data-v-e242bb46] .v-list-item__prepend .v-icon{margin-inline-end:5px!important}.list-item-main[data-v-e242bb46] .v-list-item__prepend>div{display:flex!important;align-items:center!important}.list-item-main[data-v-e242bb46] .v-list-item__content>div{padding-left:10px;padding-right:10px}.list-item--compact[data-v-e242bb46]{padding:4px}.list-item--comfortable[data-v-e242bb46]{padding:12px}
