.v-item-group{flex:0 1 auto;max-width:100%;position:relative;transition:.2s cubic-bezier(.4,0,.2,1)}.v-snackbar{justify-content:center;z-index:10000;margin:8px;margin-inline-end:calc(8px + var(--v-scrollbar-offset));padding:var(--v-layout-top) var(--v-layout-right) var(--v-layout-bottom) var(--v-layout-left)}.v-snackbar:not(.v-snackbar--center):not(.v-snackbar--top){align-items:flex-end}.v-snackbar__wrapper{align-items:center;display:flex;max-width:672px;min-height:48px;min-width:344px;overflow:hidden;padding:0}.v-snackbar__wrapper{border-radius:4px}.v-snackbar--variant-plain,.v-snackbar--variant-outlined,.v-snackbar--variant-text,.v-snackbar--variant-tonal{background:transparent;color:inherit}.v-snackbar--variant-plain{opacity:.62}.v-snackbar--variant-plain:focus,.v-snackbar--variant-plain:hover{opacity:1}.v-snackbar--variant-plain .v-snackbar__overlay{display:none}.v-snackbar--variant-elevated,.v-snackbar--variant-flat{background:rgb(var(--v-theme-surface-variant));color:rgb(var(--v-theme-on-surface-variant))}.v-snackbar--variant-elevated{box-shadow:0 3px 5px -1px var(--v-shadow-key-umbra-opacity, rgba(0, 0, 0, .2)),0 6px 10px 0 var(--v-shadow-key-penumbra-opacity, rgba(0, 0, 0, .14)),0 1px 18px 0 var(--v-shadow-key-ambient-opacity, rgba(0, 0, 0, .12))}.v-snackbar--variant-flat{box-shadow:0 0 0 0 var(--v-shadow-key-umbra-opacity, rgba(0, 0, 0, .2)),0 0 0 0 var(--v-shadow-key-penumbra-opacity, rgba(0, 0, 0, .14)),0 0 0 0 var(--v-shadow-key-ambient-opacity, rgba(0, 0, 0, .12))}.v-snackbar--variant-outlined{border:thin solid currentColor}.v-snackbar--variant-text .v-snackbar__overlay{background:currentColor}.v-snackbar--variant-tonal .v-snackbar__underlay{background:currentColor;opacity:var(--v-activated-opacity);border-radius:inherit;inset:0;pointer-events:none}.v-snackbar .v-snackbar__underlay{position:absolute}@media (forced-colors: active){.v-snackbar__wrapper{border:thick solid}}.v-snackbar__content{flex-grow:1;font-size:.875rem;font-weight:400;letter-spacing:.0178571429em;line-height:1.425;margin-right:auto;padding:14px 16px;text-align:initial}.v-snackbar__actions{align-items:center;align-self:center;display:flex;margin-inline-end:8px}.v-snackbar__actions>.v-btn{padding:0 8px;min-width:auto}.v-snackbar__timer{width:100%;position:absolute;top:0}.v-snackbar__timer .v-progress-linear{transition:.2s linear}.v-snackbar--absolute{position:absolute;z-index:1}.v-snackbar--multi-line .v-snackbar__wrapper{min-height:68px}.v-snackbar--vertical .v-snackbar__wrapper{flex-direction:column}.v-snackbar--vertical .v-snackbar__wrapper .v-snackbar__actions{align-self:flex-end;margin-bottom:8px}.v-snackbar--center{align-items:center;justify-content:center}.v-snackbar--top{align-items:flex-start}.v-snackbar--bottom{align-items:flex-end}.v-snackbar--left,.v-snackbar--start{justify-content:flex-start}.v-snackbar--right,.v-snackbar--end{justify-content:flex-end}.v-snackbar-transition-enter-active,.v-snackbar-transition-leave-active{transition-duration:.15s;transition-timing-function:cubic-bezier(0,0,.2,1)}.v-snackbar-transition-enter-active{transition-property:opacity,transform}@media (prefers-reduced-motion: reduce){.v-snackbar-transition-enter-active{transition-property:opacity}}.v-snackbar-transition-enter-from{opacity:0;transform:scale(.8)}.v-snackbar-transition-leave-active{transition-property:opacity}.v-snackbar-transition-leave-to{opacity:0}.unavailable[data-v-cf65a966],.dimmed[data-v-cf65a966]{opacity:.3}.hidden[data-v-cf65a966]{opacity:0}.hiresicon[data-v-cf65a966]{margin-top:5px;margin-right:15px;margin-left:15px;filter:invert(100%)}.hiresicondark[data-v-cf65a966]{margin-top:5px;margin-right:15px;margin-left:15px}.v-card.unavailable[data-v-bb3ba95c]{opacity:.3}.panel-item[data-v-bb3ba95c]{height:100%;padding:10px;border:none;border-style:none!important}.panel-item-checkbox[data-v-bb3ba95c]{position:absolute;width:100%;height:auto;left:0;right:0}.panel-item-details[data-v-bb3ba95c]{margin-top:10px;padding-left:0!important;padding-right:0!important;height:40px}.panel-item-actions[data-v-bb3ba95c]{padding:0;margin:10px 0 0;height:40px;min-height:unset!important}panel-item-details[data-v-bb3ba95c] .v-list-item__content{height:30px}.v-card--active[data-v-bb3ba95c]{background-color:red}.hiresicon[data-v-bb3ba95c]{margin-right:10px}.hiresiconinverted[data-v-bb3ba95c]{margin-right:10px;filter:invert(100%)}.col-2[data-v-599e3d6b]{width:50%;max-width:50%;flex-basis:50%;padding:8px}.col-3[data-v-599e3d6b]{width:33.3%;max-width:33.3%;flex-basis:33.3%;padding:8px}.col-4[data-v-599e3d6b]{width:25%;max-width:25%;flex-basis:25%;padding:8px}.col-5[data-v-599e3d6b]{width:20%;max-width:20%;flex-basis:20%;padding:8px}.col-6[data-v-599e3d6b]{width:16.6%;max-width:16.6%;flex-basis:16.6%;padding:8px}.col-7[data-v-599e3d6b]{width:14.2%;max-width:14.2%;flex-basis:14.2%;padding:8px}.col-8[data-v-599e3d6b]{width:12.5%;max-width:12.5%;flex-basis:12.5%;padding:8px}.col-9[data-v-599e3d6b]{width:11.1%;max-width:11.1%;flex-basis:11.1%;padding:8px}
